======================================================================
 :mod:`xoeuf.osv.orm` -- OpenERP's Basic ORM extensions and utilities
======================================================================

.. automodule:: xoeuf.osv.orm


.. autofunction:: CREATE_RELATED(**values)

.. autofunction:: UPDATE_RELATED(id, **values)

.. autofunction:: REMOVE_RELATED(id)

.. autofunction:: FORGET_RELATED(id)

.. autofunction:: LINK_RELATED(id)

.. autofunction:: UNLINKALL_RELATED()

.. autofunction:: REPLACEWITH_RELATED(*ids)
